//! The Binding library is a place where common macros and functions
//! that are used when interfacing with C libraries can be stored
//! for use amoungst all of CyberMages LLC's projects.

// Handle using the core or the std of Rust depending on the chosen feature.
#![cfg_attr(not(feature="use_std"), no_std)]

// This crate can only use parts of Rust that are in both the core
// and the standard library. This way the logging system will work for
// libraries that use either.
//
// This is handled by coding using the std library and referencing the core
// library as the std library if the core library is desired.
#[cfg(not(feature="use_std"))]
extern crate core as std;



// Basic C type macro modules.
mod c_enum;
mod c_flags;
mod c_types;

// Raw platform data retrieval.
mod raw;

// Macros to help create bindings to FFI libraries.
mod macros;



pub use self::c_types::{CChar, CUChar};
pub use self::c_types::{CShort, CUShort, CInt, CUInt, CLong, CULong};
pub use self::c_types::{CLongLong, CULongLong, CFloat, CDouble};
pub use self::c_types::{CVoid, CReturnVoid};
#[cfg(feature="use_std")]
pub use self::c_types::{CStr, CString, NullByteError};
pub use self::raw::{AsRaw, AsRawMut, AsRawPtr, AsRawMutPtr, FromRaw, IntoRaw};
